==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/nl.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Documenten",
"Can't create document" => "Kan document niet creëren",
"You don't have permission to rename this document" => "U hebt niet de autorisatie om die document te hernoemen",
"Directory saved successfully." => "Directory succesvol bewaard.",
"An error occurred while changing directory." => "Er trad een fout op bij het wijzigen van de directory",
"Saved" => "Bewaard",
"Format filter server is down or misconfigured" => "Formaatfilter server is down of onjuist geconfigureerd",
"Conversion failed. Check log for details." => "Conversie mislukt. Beoordeel log voor details.",
"document-styles" => "documentstijlen",
"document-content" => "document inhoud",
"bold" => "vet",
"italic" => "schuin",
"solid" => "dicht",
"pt" => "pt",
"Saving..." => "Opslaan",
"Failed to load documents." => "Kon documenten niet laden.",
"No documents were found. Upload or create a document to get started!" => "Geen documenten gevonden. Upload of maak een document om  te starten!",
"No connection to server. Trying to reconnect." => "Geen verbinding met de server. Bezig te verbinden.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Deze pagina open laten in de Editor kan resulteren in niet opslaan. Geadviseerd wordt om de 'Sluiten' knop te gebruiken.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Kon dit document niet laden. Ga na of het met een externe odt editor wel kan worden geopend. Het kan zijn dat het niet meer is gedeeld of dat het recent is verwijderd.",
"Save" => "Bewaren",
"Loading documents..." => "Laden documenten...",
"'.' is an invalid file name." => "'.' is een ongeldige bestandsnaam.",
"File name cannot be empty." => "Bestandsnaam kan niet leeg zijn.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Onjuiste naam; '\\', '/', '<', '>', ':', '\"', '|', '?' en '*' zijn niet toegestaan.",
"Align Left" => "Links uitlijnen",
"Alignment" => "Uitlijning",
"Align Right" => "Rechts uitlijnen",
"Annotate" => "Opmerkingen",
"Background" => "Achtergrond",
"Bold" => "Vet",
"Bottom" => "Onderaan",
"Cancel" => "Annuleer",
"Center" => "Gecentreerd",
"Clone" => "Klonen",
"Clone this Style" => "Deze Stijl klonen",
"Close" => "Sluiten",
"Color" => "Kleur",
"Create" => "Creëer",
"Decrease Indent" => "Minder inspringen",
"Default Style" => "Standaard Stijl",
"Delete" => "Verwijder",
"Family" => "Familie",
"Font" => "Lettertype",
"Font Effects" => "Lettertype effecten",
"Format" => "Afmeting",
"Increase Indent" => "Meer inspringen",
"Insert Image" => "Invoegen afbeelding",
"Invite Members" => "Uitnodigen leden",
"Italic" => "Schuin",
"Justified" => "Uitgelijnd",
"Justify" => "Uitlijnen",
"Left" => "Links",
"Loading" => "Ladend",
"Members" => "Leden",
"New Name:" => "Nieuwe naam:",
"OK" => "OK",
"Open" => "Open",
"Options" => "Opties",
"Paragraph..." => "Paragraaf...",
"Paragraph Styles" => "Paragraaf Stijlen",
"Redo" => "Opnieuw",
"Right" => "Rechts",
"Size" => "Grootte",
"Spacing" => "Spatiëring",
"Strikethrough" => "Doorhalen",
"Style" => "Stijl",
"Text" => "Tekst",
"Top" => "Bovenaan",
"Underline" => "Onderstrepen",
"Undo" => "Ongedaan maken",
"Unknown Author" => "Onbekende auteur",
"Edit" => "Bewerk",
"Share" => "Delen",
"guest" => "gast",
"MS Word support (requires openOffice/libreOffice)" => "MS Word ondersteuning (vereist openOffice/libreOffice)",
"Local" => "Lokaal",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice is geïnstalleerd op deze server. Pad naar executable is beschikbaar via preview_libreoffice_path in config.php",
"External" => "Extern",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice is geïnstalleerd op een externe server die een format filter server draait",
"Disabled" => "Gedeactiveerd",
"No MS Word support" => "Geen MS Word ondersteuning",
"scheme://domain.tld[:port]" => "scheme://domain.tld[:port]",
"Server URL" => "Server URL",
"Apply and test" => "Toepassen en testen",
"New document" => "Nieuw document",
"Upload (max. %s)" => "Upload (max. %s)",
"Upload" => "Uploaden",
"Save new documents to" => "Bewaar nieuwe documenten  in",
"Wrong password. Please retry." => "Onjuist wachtwoord. Probeer opnieuw.",
"Password" => "Wachtwoord",
"Guest %s" => "Gast %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "De link is vervallen of heeft nooit bestaan. Neem contact op met de persoon die het deelde voor de details.",
"Advanced feature-set" => "Geavanceerde functies",
"(Unstable)" => "(Onstabiel)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud-app-documents-1%3A0.13.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/nl.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Documenten",
"Can't create document" => "Kan document niet creëren",
"You don't have permission to rename this document" => "U hebt niet de autorisatie om die document te hernoemen",
"File does not exist" => "Bestand bestaat niet",
"Directory saved successfully." => "Directory succesvol bewaard.",
"An error occurred while changing directory." => "Er trad een fout op bij het wijzigen van de directory",
"Saved" => "Bewaard",
"Format filter server is down or misconfigured" => "Formaatfilter server is down of onjuist geconfigureerd",
"Conversion failed. Check log for details." => "Conversie mislukt. Beoordeel log voor details.",
"Saving..." => "Opslaan",
"Failed to load documents." => "Kon documenten niet laden.",
"No documents were found. Upload or create a document to get started!" => "Geen documenten gevonden. Upload of maak een document om  te starten!",
"No connection to server. Trying to reconnect." => "Geen verbinding met de server. Bezig te verbinden.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Deze pagina open laten in de Editor kan resulteren in niet opslaan. Geadviseerd wordt om de 'Sluiten' knop te gebruiken.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Kon dit document niet laden. Ga na of het met een externe odt editor wel kan worden geopend. Het kan zijn dat het niet meer is gedeeld of dat het recent is verwijderd.",
"Save" => "Bewaren",
"Loading documents..." => "Laden documenten...",
"'.' is an invalid file name." => "'.' is een ongeldige bestandsnaam.",
"File name cannot be empty." => "Bestandsnaam kan niet leeg zijn.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Onjuiste naam; '\\', '/', '<', '>', ':', '\"', '|', '?' en '*' zijn niet toegestaan.",
"Align Left" => "Links uitlijnen",
"Alignment" => "Uitlijning",
"Align Right" => "Rechts uitlijnen",
"Annotate" => "Opmerkingen",
"Background" => "Achtergrond",
"Bold" => "Vet",
"Bottom" => "Onderaan",
"Cancel" => "Annuleer",
"Center" => "Gecentreerd",
"Clone" => "Klonen",
"Clone this Style" => "Deze Stijl klonen",
"Close" => "Sluiten",
"Color" => "Kleur",
"Create" => "Creëer",
"Decrease Indent" => "Minder inspringen",
"Default Style" => "Standaard Stijl",
"Delete" => "Verwijder",
"Family" => "Familie",
"Font" => "Lettertype",
"Font Effects" => "Lettertype effecten",
"Format" => "Afmeting",
"Increase Indent" => "Meer inspringen",
"Insert Image" => "Invoegen afbeelding",
"Invite Members" => "Uitnodigen leden",
"Italic" => "Schuin",
"Justified" => "Uitgelijnd",
"Justify" => "Uitlijnen",
"Left" => "Links",
"Loading" => "Ladend",
"Members" => "Leden",
"New Name:" => "Nieuwe naam:",
"OK" => "OK",
"Open" => "Open",
"Options" => "Opties",
"Paragraph..." => "Paragraaf...",
"Paragraph Styles" => "Paragraaf Stijlen",
"Redo" => "Opnieuw",
"Right" => "Rechts",
"Size" => "Grootte",
"Spacing" => "Spatiëring",
"Strikethrough" => "Doorhalen",
"Style" => "Stijl",
"Text" => "Tekst",
"Top" => "Bovenaan",
"Underline" => "Onderstrepen",
"Undo" => "Ongedaan maken",
"Unknown Author" => "Onbekende auteur",
"Shared" => "Gedeeld",
"Error" => "Fout",
"Error while sharing" => "Fout tijdens het delen",
"Error while unsharing" => "Fout tijdens het stoppen met delen",
"Error while changing permissions" => "Fout tijdens het veranderen van permissies",
"Shared with you and the group {group} by {owner}" => "Gedeeld met u en de groep {group} door {owner}",
"Shared with you by {owner}" => "Gedeeld met u door {owner}",
"Share with users or groups …" => "Delen met gebruikers of groepen ...",
"Share with users, groups or remote users …" => "Delen met gebruikers, groepen of externe gebruikers ...",
"Share" => "Delen",
"Share with people on other ownClouds using the syntax username@example.com/owncloud" => "Delen met mensen op andere ownClouds via de syntax gebruikersnaam@voorbeeld.org/owncloud",
"Share link" => "Deel link",
"The public link will expire no later than {days} days after it is created" => "De openbare link vervalt niet eerder dan {days} dagen na het aanmaken",
"Link" => "Link",
"Password protect" => "Wachtwoord beveiligd",
"Password" => "Wachtwoord",
"Choose a password for the public link" => "Kies een wachtwoord voor de openbare link",
"Allow editing" => "Toestaan bewerken",
"Email link to person" => "E-mail link naar persoon",
"Send" => "Versturen",
"Set expiration date" => "Stel vervaldatum in",
"Expiration" => "Vervaltermijn",
"Expiration date" => "Vervaldatum",
"An error occured. Please try again" => "Er trad een fout op. Probeer het opnieuw",
"Adding user..." => "Toevoegen gebruiker...",
"group" => "groep",
"remote" => "extern",
"Resharing is not allowed" => "Verder delen is niet toegestaan",
"Shared in {item} with {user}" => "Gedeeld in {item} met {user}",
"Unshare" => "Stop met delen",
"notify by email" => "melden per e-mail",
"can share" => "kan delen",
"can edit" => "kan wijzigen",
"access control" => "toegangscontrole",
"create" => "creëer",
"change" => "wijzig",
"delete" => "verwijderen",
"Password protected" => "Wachtwoord beveiligd",
"Error unsetting expiration date" => "Fout tijdens het verwijderen van de vervaldatum",
"Error setting expiration date" => "Fout tijdens het instellen van de vervaldatum",
"Sending ..." => "Versturen ...",
"Email sent" => "E-mail verzonden",
"Warning" => "Waarschuwing",
"Edit" => "Bewerk",
"guest" => "gast",
"MS Word support (requires openOffice/libreOffice)" => "MS Word ondersteuning (vereist openOffice/libreOffice)",
"Local" => "Lokaal",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice is geïnstalleerd op deze server. Pad naar executable is beschikbaar via preview_libreoffice_path in config.php",
"External" => "Extern",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice is geïnstalleerd op een externe server die een format filter server draait",
"Disabled" => "Gedeactiveerd",
"No MS Word support" => "Geen MS Word ondersteuning",
"scheme://domain.tld[:port]" => "scheme://domain.tld[:port]",
"Server URL" => "Server URL",
"Apply and test" => "Toepassen en testen",
"New document" => "Nieuw document",
"Upload (max. %s)" => "Upload (max. %s)",
"Upload" => "Uploaden",
"Save new documents to" => "Bewaar nieuwe documenten  in",
"Wrong password. Please retry." => "Onjuist wachtwoord. Probeer opnieuw.",
"Guest %s" => "Gast %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "De link is vervallen of heeft nooit bestaan. Neem contact op met de persoon die het deelde voor de details.",
"Advanced feature-set" => "Geavanceerde functies",
"(Unstable)" => "(Onstabiel)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
